@@ -73,7 +73,7 @@ sub day_length {
     exists $RD_LENGTH{ $_[0] } ? 86400 + $RD_LENGTH{ $_[0] } : 86400
 }
 
-sub initialize {
+sub _initialize {
     # this table: ftp://62.161.69.5/pub/tai/publication/leaptab.txt
     # known accurate until (at least): 2005-12-31
     #
@@ -106,10 +106,11 @@ sub initialize {
 1997  Jul. 1  +1
 1999  Jan. 1  +1
 2006  Jan. 1  +1
+2009  Jan. 1  +1
     ) );
 }
 
-__PACKAGE__->initialize;
+__PACKAGE__->_initialize();
 
 1;
 __END__
